@@ -339,8 +339,7 @@ class Worker:
     def _enqueue(self, request_id):
         self.queue.send_message(base64.b64encode(request_id.encode()).decode())
 
-    @staticmethod
-    def _read_blob_by_chunks(input_blob):
+    def _read_blob_by_chunks(self, input_blob):
         blob_data = input_blob.download_blob()
         last_piece = ""
         for chunk in blob_data.chunks():
@@ -349,23 +348,27 @@ class Worker:
             last_piece = lines[-1]
             source_segments = []
             for l in lines[:-1]:
-                l = unicodedata.normalize("NFKD", l).strip()
+                l = self._preprocess(l)
                 if len(l) == 0:
                     continue
-                source_segment = json.loads(l)[0].strip()
+                source_segment = self._preprocess(json.loads(l)[0])
                 source_segments.append(source_segment)
             yield source_segments
 
-        last_piece = unicodedata.normalize("NFKD", last_piece).strip()
+        last_piece = self._preprocess(last_piece)
         if len(last_piece) > 0:
             source = None
             try:
-                source = json.loads(last_piece)[0].strip()
+                source = self._preprocess(json.loads(last_piece)[0])
             except:
                 pass
             if source:
                 yield [source]
 
+    @staticmethod
+    def _preprocess(text):
+        return text.replace("\xa0", " ").replace("&nbsp;", " ").strip()
+
     @staticmethod
     def _read_blob_by_segments(input_blob):
         blob_data = input_blob.download_blob()
